==> shops-service-1.2.0-sources.jar: com/bxm/shop/interceptors/profit/ParentInterceptor.java <==
package com.bxm.shop.interceptors.profit;

import com.bxm.shop.common.enums.ProfitTypeEnum;
import com.bxm.shop.common.utils.CustomParameterUtils;
import com.bxm.shop.model.user.dao.UserDao;
import com.bxm.warcar.integration.interceptor.AbstractInterceptor;
import com.bxm.warcar.integration.interceptor.Invocation;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

/**
 * 上级返利处理
 * @author bcc
 */
@Component
public class ParentInterceptor extends AbstractProfitInterceptor  {

    @Override
    public String getProfittype() {
        return ProfitTypeEnum.PARENT.getCode();
    }

    @Override
    public Long getProfitAmount(ProfitRequestModel requestModel) {
        long promotionAmount = 0L;
        if(null != requestModel.getPddOrderInfo().getPromotionAmount()){
            promotionAmount = requestModel.getPddOrderInfo().getPromotionAmount();
        }
        return promotionAmount * requestModel.getRebateConfig().getPre() / 100;
    }

    @Override
    public String getProfitOwner(ProfitRequestModel requestModel) {
        String openid = CustomParameterUtils.getOpenid(requestModel.getPddOrderInfo().getCustomParameters());
        UserDao userDao = getUserDao(requestModel, openid);
        return userDao.getParentOpenid();
    }

    @Override
    public Boolean needSaveOrUpdate(ProfitRequestModel requestModel) {
        String openid = CustomParameterUtils.getOpenid(requestModel.getPddOrderInfo().getCustomParameters());
        if(StringUtils.isBlank(openid)){
            openid = requestModel.getOrderDao().getOpenid();
        }
        UserDao userDao = getUserDao(requestModel, openid);
        //存在上级用户，且上级返利金额大于0
        if(null != userDao && StringUtils.isNotBlank(userDao.getParentOpenid())&&
                requestModel.getRebateConfig().getPre()>0 && null != requestModel.getPddOrderInfo().getPromotionAmount() &&
                requestModel.getPddOrderInfo().getPromotionAmount()>0){
            return true;
        }
        return false;
    }

}

==> shops-service-1.3.5-sources.jar: com/bxm/shop/interceptors/profit/ParentInterceptor.java <==
package com.bxm.shop.interceptors.profit;

import com.bxm.shop.common.enums.ProfitTypeEnum;
import com.bxm.shop.common.utils.CustomParameterUtils;
import com.bxm.shop.dal.UserDao;
import lombok.extern.slf4j.Slf4j;
import org.apache.commons.lang3.StringUtils;
import org.springframework.stereotype.Component;

/**
 * 上级返利处理
 * @author bcc
 */
@Component
@Slf4j
public class ParentInterceptor extends AbstractProfitInterceptor  {

    @Override
    public String getProfittype() {
        return ProfitTypeEnum.PARENT.getCode();
    }

    @Override
    public Long getProfitAmount(ProfitRequestModel requestModel) {
        long promotionAmount = 0L;
        if(null != requestModel.getPddOrderInfo().getPromotionAmount()){
            promotionAmount = requestModel.getPddOrderInfo().getPromotionAmount();
        }
        return promotionAmount * requestModel.getRebateConfig().getPre() / 100;
    }

    @Override
    public String getProfitOwner(ProfitRequestModel requestModel) {
        String openid = CustomParameterUtils.getOpenid(requestModel.getPddOrderInfo().getCustomParameters());
        UserDao userDao = getUserDao(requestModel, openid);
        return userDao.getParentOpenid();
    }

    @Override
    public Boolean needSaveOrUpdate(ProfitRequestModel requestModel) {
        String openid = CustomParameterUtils.getOpenid(requestModel.getPddOrderInfo().getCustomParameters());
        if(StringUtils.isBlank(openid)){
            openid = requestModel.getOrderDao().getOpenid();
        }
        UserDao userDao = getUserDao(requestModel, openid);
        //存在上级用户，且上级返利金额大于0
        if(null != userDao && StringUtils.isNotBlank(userDao.getParentOpenid())&&
                requestModel.getRebateConfig().getPre()>0 && null != requestModel.getPddOrderInfo().getPromotionAmount() &&
                requestModel.getPddOrderInfo().getPromotionAmount()>0){
            return true;
        }
        return false;
    }

}
